#
# spec file for package python-xmldiff
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
Name:           python-xmldiff
Version:        2.7.0
Release:        1.5
Summary:        Tree to tree correction between XML documents
License:        MIT
URL:            https://github.com/Shoobx/xmldiff
Source:         https://files.pythonhosted.org/packages/source/x/xmldiff/xmldiff-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-lxml >= 3.1.0
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
Conflicts:      %{oldpython}-xmldiff < %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module lxml >= 3.1.0}
# /SECTION
%python_subpackages

%description
XMLdiff shows the differences between two similar XML files in the same
way `diff` does with text files. It can also be used as a library or as
a command line tool and can work either with XML files or DOM trees.
The implementation is based on "Change detection in hierarchically
structured information", by S. Chawathe, A. Rajaraman, H.
Garcia-Molina, and J. Widom, Stanford University, 1996.

%prep
%autosetup -p1 -n xmldiff-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/xmlpatch
%python_clone -a %{buildroot}%{_bindir}/xmldiff
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v

%post
%python_install_alternative xmlpatch
%python_install_alternative xmldiff

%postun
%python_uninstall_alternative xmlpatch
%python_uninstall_alternative xmldiff

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/xmldiff
%python_alternative %{_bindir}/xmlpatch
%{python_sitelib}/xmldiff
%{python_sitelib}/xmldiff-%{version}.dist-info

%changelog
* Tue Nov  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.7.0
  * Changed the comparison to make accurate and standard more accurate,
    although fast gets less accurate as a result.
  * Changed usage of deprecated `pkg_resources` package to `importlib.metadata`.
  * A `use_replace` flag was added to the `XMLFormatter` by Thomas Pfitzinger.
    It changes text replacement from delete and insert tags to a replace tag.
    It's not currently accessaible thtough the CLI, the question is it is better
    to add a new formatter name, or an option to pass in formatter flags.
    + Added option to XMLFormatter to use replace tags
    + in _make_diff_tags after diffing, neighboring delete/insert diffs are
    joined to a replace tag
    + the deleted text is added as an attribute ("old-text")
    + the inserted text is the element's text
- Drop README.txt from %%files section, removed upstream
* Tue Mar  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.6.3:
  * Solved an error in the xmlformatter when using default namespaces. #89
  * #108: Fixed an error that happens if using namespaces like ns0 or ns1.
  * Added `InsertNamespace` and `DeleteNamespace` actions for better handling
    of changing namespaces. Should improve any "Unknown namespace prefix"
    errors. Changing the URI of a a namespace prefix is not supported, and
    will raise an error.
  * Used geometric mean for the node_ratio, for better handling of simple nodes.
  * Added an experimental --best-match method that is slower, but generate
    smaller diffs when you have many nodes that are similar.
  * The -F argument now also affects the --fast-match stage.
  * Make it possible to adjust the attributes considered when comparing nodes.
  * Python versions 3.7 to 3.11 are now supported.
  * Improved node matching method, that puts more emphasis similarities than
    differences when weighing attributes vs children.
  * Added a parameter to return error code 1 when there are differences
    between the files
  * Added a parameter for ignoring attributes in comparison.
  * Solved a bug in xmlpatch in certain namespace situations.
  * Added a --diff-encoding parameter to xmlpatch, to support diff-files
    that are not in your system default encoding.
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
- Drop python-xmldiff-src-upgrades.patch, now included upstream.
- Drop python-xmldiff-no-six-remains.patch, no longer required.
* Fri Oct 14 2022 pgajdos@suse.com
- added patches
  fix https://github.com/Shoobx/xmldiff/commit/34b810f4394965aadeca31204e6b76eb023fd11a
  + python-xmldiff-src-upgrades.patch
  https://github.com/Shoobx/xmldiff/issues/93
  + python-xmldiff-no-six-remains.patch
* Thu Jun  3 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Fri May 15 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4:
  * Added an option to pass pairs of (element, attr) as unique
    attributes for tree matching.
* Fri Apr 12 2019 Matej Cepl <mcepl@suse.com>
- Conflict python-xmldiff (unversioned)
* Wed Apr 10 2019 Jan Engelhardt <jengelh@inai.de>
- Restore more useful description from before 2.3
* Tue Apr  9 2019 pgajdos@suse.com
- package reworked from scratch
- version update to 2.3
  - A complete, bottom-up, pure-python rewrit
  - A new default output format with new actions
  - A format intended to be parseable by anyone parsing the old format.
  - XML with changes marked though tags and attributes
  - Added options for faster node comparisons. The "middle" option is now
    default, it had very few changes in matches, but is much faster.
  - Implemented a Fast Match algorithm for even faster diffing.
  - Speed improvements through caching
  - Fixed a bug where MoveNode actions sometimes was in the wrong order
  - Added an InsertComment action, as comments require different handling,
    so it's easier to deal with them this way. You can still use DeleteNode and
    UpdateTextIn for them with no special handling.
  - When renaming tags the XMLFormatter will mark them with "diff:rename"
    instead of making a new tag and deleting the old.
  - Tags will now be moved first, and updated and renamed later, as the new
    tag name or attributes might not be valid in the old location.
  - Changed the substitution unicode character area to use the Private Use Area
    in BMP(0), to support narrow Python builds
  - Added --unique-attributes argument.
  - A workaround for dealing with top level comments and the xml formatter
  - Added a simple ``xmlpatch`` command and API.
  - Multiple updates to documentation and code style
- deleted patches
  - xmldiff-0.6.7-clean-tmp.patch (not needed)
  - xmldiff-0.6.7-xsldata.patch (not needed)
* Sat May 28 2011 dimstar@opensuse.org
- Update to version 0.6.10:
  + fails when comparing minimal trees on i386
- Changes from version 0.6.9:
  + Fixed xmldiff-xmlrev compilation error.
- Spec file cleanup
- Drop patches: xmldiff-0.6.8-python2.5.patch
* Mon Jan 15 2007 ke@suse.de
- Remove /usr/share/xml from the files list.
* Tue Sep 26 2006 cthiel@suse.de
- fix build with python 2.5
- update to version 0.6.8
  * various fixes
- removed xmldiff-0.6.7-x64safe.patch
* Fri Jun  2 2006 cthiel@suse.de
- specfile cleanup, added Requires
- imported 3 patches from Fedora
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec  7 2005 ke@suse.de
- Update to version 0.6.7.
- Drop obsolete tmp file patch.
* Thu Oct 23 2003 ke@suse.de
- New package: version 0.6.4.
